@@ -732,6 +732,7 @@ class SnapAdmin:
         :return: return list of object of testop.Operator containing test details or list of dictionary of object
                     of testop.Operator containing test details for each stored snapshot
         """
+        self.host_list = []
         try:
             host = config_data.get('hosts')[0]
         except Exception as ex:
@@ -858,6 +859,9 @@ class SnapAdmin:
         :return: return list of object of testop.Operator containing test details or list of dictionary of object
                     of testop.Operator containing test details for each stored snapshot
         """
+        if pre_file is None:
+            pre_file = "snap_temp"
+            self.snap_del = True
         return self.action_api_based(dev, data, pre_file, "snapcheck", folder, local=local)
 
     def check(self, data, pre_file=None, post_file=None, dev=None, folder=None):
