@@ -5,5 +5,5 @@
 # All rights reserved.
 #
 
-__version__ = "1.3.5"
-DATE = "2020-dec-22"
+__version__ = "1.3.6"
+DATE = "2021-feb-26"
